Package: meshes
Title: MeSH Enrichment and Semantic analyses
Version: 1.39.0
Authors@R: c( person(given = "Guangchuang", family = "Yu",        email = "guangchuangyu@gmail.com",   role = c("aut", "cre")))
Description: MeSH (Medical Subject Headings) is the NLM controlled vocabulary
	     used to manually index articles for MEDLINE/PubMed. MeSH terms were
	     associated by Entrez Gene ID by three methods, gendoo, gene2pubmed and RBBH.
	     This association is fundamental for enrichment and semantic analyses.
	     meshes supports enrichment analysis (over-representation and gene set
	     enrichment analysis) of gene list or whole expression profile.
	     The semantic comparisons of MeSH terms provide quantitative ways to compute
	     similarities between genes and gene groups. meshes implemented five methods
	     proposed by Resnik, Schlicker, Jiang, Lin and Wang respectively and supports
	     more than 70 species.
Depends: R (>= 4.1.0)
Imports: enrichit, gson, AnnotationDbi, GOSemSim (> 2.37.0), methods,
        utils, AnnotationHub, MeSHDbi, yulab.utils (>= 0.1.5)
Suggests: knitr, rmarkdown, prettydoc
VignetteBuilder: knitr
ByteCompile: true
License: Artistic-2.0
URL: https://yulab-smu.top/biomedical-knowledge-mining-book/
BugReports: https://github.com/GuangchuangYu/meshes/issues
biocViews: Annotation, Clustering, MultipleComparison, Software
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
git_url: https://git.bioconductor.org/packages/meshes
git_branch: devel
git_last_commit: 5e7025f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:37:51 UTC; biocbuild
Author: Guangchuang Yu [aut, cre]
Maintainer: Guangchuang Yu <guangchuangyu@gmail.com>
