##' @importMethodsFrom enrichit show
##' @importMethodsFrom enrichit summary
##'
##' @importFrom enrichit geneID
##' @export
enrichit::geneID

##' @importFrom enrichit geneInCategory
##' @export
enrichit::geneInCategory

##' @importFrom GOSemSim get_organism
##' @export
GOSemSim::get_organism
