---
title: "MeSH Enrichment and Semantic Analyses"
author: 
- name: Guangchuang Yu
  email: guangchuangyu@gmail.com
  affiliation: Department of Bioinformatics, School of Basic Medical Sciences, Southern Medical University
date: "`r Sys.Date()`"
biblio-style: apalike
output:
  prettydoc::html_pretty:
    toc: true
    theme: cayman
    highlight: github
  pdf_document:
    toc: true
vignette: >
  % \VignetteIndexEntry{meshes}
  % \VignetteEngine{knitr::rmarkdown}
  % \usepackage[utf8]{inputenc}
  %\VignetteEncoding{UTF-8}
---

```{r style, echo=FALSE, results="asis", message=FALSE}
knitr::opts_chunk$set(tidy = FALSE,
                      warning = FALSE,
                      message = FALSE)
```

```{r echo=FALSE, results="hide", message=FALSE}
Biocpkg <- function (pkg) {
    sprintf("[%s](http://bioconductor.org/packages/%s)", pkg, pkg)
}
```



# Vignette

Please go to <https://yulab-smu.top/biomedical-knowledge-mining-book/> for the full vignette.


# Citation

If you use `r Biocpkg("meshes")` in published research, please cite the most appropriate paper(s):

__*G Yu*__. Using meshes for MeSH term enrichment and semantic analyses. __*Bioinformatics*__ 2018, 34(21):3766-3767. <https://dx.doi.org/10.1093/bioinformatics/bty410>.


# Need helps?


If you have questions/issues, please post to [Bioconductor support site](https://support.bioconductor.org/) and tag your post with *meshes*.


