% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utilities.R
\name{meshdata}
\alias{meshdata}
\title{meshdata}
\usage{
meshdata(MeSHDb = NULL, database, category, computeIC = FALSE)
}
\arguments{
\item{MeSHDb}{MeSHDb package}

\item{database}{one of supported database}

\item{category}{one of supported category}

\item{computeIC}{logical value}
}
\value{
a GOSemSimDATA object
}
\description{
construct annoData for semantic measurement
}
\examples{
\dontrun{
library(meshes)
library(AnnotationHub)
ah <- AnnotationHub()
qr_hsa <- query(ah, c("MeSHDb", "Homo sapiens"))
filepath_hsa <- qr_hsa[[1]]
db <- MeSHDbi::MeSHDb(filepath_hsa)
hsamd <- meshdata(db, category='A', computeIC=T, database="gendoo")
}
}
\author{
Guangchuang Yu
}
