% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DOSE.R
\docType{import}
\name{reexports}
\alias{reexports}
\alias{geneID}
\alias{geneInCategory}
\alias{get_organism}
\title{Objects exported from other packages}
\keyword{internal}
\description{
These objects are imported from other packages. Follow the links
below to see their documentation.

\describe{
  \item{enrichit}{\code{\link[enrichit]{geneID}}, \code{\link[enrichit]{geneInCategory}}}

  \item{GOSemSim}{\code{\link[GOSemSim]{get_organism}}}
}}

